# Generated by Django 4.2.7 on 2023-11-16 13:54

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("wbcommission", "0004_rebate_audit_log"),
    ]

    operations = [
        migrations.AlterField(
            model_name="rebate",
            name="audit_log",
            field=models.JSONField(
                default=dict, encoder=django.core.serializers.json.DjangoJSONEncoder, verbose_name="Audit Log"
            ),
        ),
    ]
